# -*- coding: utf-8 -*-
"""
    wakadump
    ~~~~~~~~

    Command line tool for converting WakaTime data dump files into various formats.

    http://wakatime.com

    :copyright: (c) 2015 Alan Hamlett.
    :license: BSD, see LICENSE for more details.
"""
